==> gqview_1.0.2.orig.tar.gz: gqview-1.0.2.orig/src/globals.c <==
/*
 * GQview
 * (C) 2001 John Ellis
 *
 * Author: John Ellis
 *
 * This software is released under the GNU General Public License (GNU GPL).
 * Please read the included file COPYING for more information.
 * This software comes with no warranty of any kind, use at your own risk!
 */


#include "gqview.h"
#include "logo.xpm"
#include "icons/img_unknown.xpm"

/* image */
ImageWindow *main_image = NULL;

/* main window */
GtkWidget *mainwindow;
GtkWidget *mainwindow_hbox;
GtkWidget *mainwindow_vbox;
GtkAccelGroup *mainwindow_accel_grp;

GtkWidget *info_box = NULL;
GtkWidget *info_progress_bar;
GtkWidget *info_status;
GtkWidget *info_details;
GtkWidget *info_zoom;

/* full screen */
ImageWindow *normal_image = NULL;
ImageWindow *full_screen_image = NULL;
GtkWidget *full_screen_window = NULL;

/* tools floating window */
GtkWidget *toolwindow = NULL;

/* tools */
GtkWidget *tool_vbox;

GtkWidget *path_entry;
GtkWidget *history_menu;

GtkWidget *dir_clist;
GtkWidget *file_clist;

GtkItemFactory *gqview_fact;

GtkWidget *thumb_button;

gchar *current_path = NULL;

GList *filename_filter = NULL;

/* -- options -- */
gint main_window_w = 400;
gint main_window_h = 350;
gint main_window_x = 0;
gint main_window_y = 0;

gint float_window_w = 150;
gint float_window_h = 350;
gint float_window_x = 0;
gint float_window_y = 0;

gint main_window_vdivider_pos = 100;

gint save_window_positions = FALSE;
gint tools_float = FALSE;
gint tools_hidden = FALSE;
gint progressive_key_scrolling = FALSE;

gint startup_path_enable = FALSE;
gchar *startup_path = NULL;
gint confirm_delete = TRUE;
gint enable_delete_key = TRUE;
gint restore_tool = FALSE;
gint zoom_mode = ZOOM_RESET_ORIGINAL;
gint fit_window = FALSE;
gint limit_window_size = FALSE;
gint zoom_to_fit_expands = TRUE;
gint max_window_size = 100;
gint thumb_max_width = 64;
gint thumb_max_height = 64;
gint enable_thumb_caching = FALSE;
gint enable_thumb_dirs = FALSE;
gint use_xvpics_thumbnails = TRUE;
gint show_dot_files = FALSE;
gint file_filter_disable = FALSE;
gint filter_include_jpg = TRUE;
gint filter_include_xpm = TRUE;
gint filter_include_tif = TRUE;
gint filter_include_gif = TRUE;
gint filter_include_png = TRUE;
gint filter_include_ppm = TRUE;
gint filter_include_pgm = TRUE;
gint filter_include_pcx = TRUE;
gint filter_include_bmp = TRUE;
gchar *custom_filter = NULL;
gchar *editor_name[8];
gchar *editor_command[8];

gint thumbnails_enabled = FALSE;
SortType file_sort_method = SORT_NAME;
gint file_sort_ascending = TRUE;

gint slideshow_delay = 15;
gint slideshow_random = FALSE;
gint slideshow_repeat = FALSE;

gint mousewheel_scrolls = TRUE;
gint enable_in_place_rename = TRUE;

gint recent_list_max = 10;

gint collection_rectangular_selection = FALSE;
gint collection_drop_insert = TRUE;

gint tile_cache_max = 10;
gint thumbnail_quality = (gint)GDK_INTERP_NEAREST;
gint zoom_quality = (gint)GDK_INTERP_NEAREST;
gint dither_quality = (gint)GDK_RGB_DITHER_NORMAL;

gint zoom_increment = 5;

gint enable_read_ahead = TRUE;

gint place_dialogs_under_mouse = TRUE;

gint debug = FALSE;

/* logo & misc images */

const char **logo = (const char **)logo_xpm;
const char **img_unknown = (const char **)img_unknown_xpm;

==> gqview-1.2.2.tar.gz: gqview-1.2.2/src/globals.c <==
/*
 * GQview
 * (C) 2003 John Ellis
 *
 * Author: John Ellis
 *
 * This software is released under the GNU General Public License (GNU GPL).
 * Please read the included file COPYING for more information.
 * This software comes with no warranty of any kind, use at your own risk!
 */


#include "gqview.h"
#include "logo.xpm"
#include "icons/img_unknown.xpm"


GList *filename_filter = NULL;

/* -- options -- */
gint main_window_w = 400;
gint main_window_h = 350;
gint main_window_x = 0;
gint main_window_y = 0;

gint float_window_w = 150;
gint float_window_h = 350;
gint float_window_x = 0;
gint float_window_y = 0;
gint float_window_divider = -1;

gint window_hdivider_pos = -1;
gint window_vdivider_pos = 200;

gint save_window_positions = FALSE;
gint tools_float = FALSE;
gint tools_hidden = FALSE;
gint toolbar_hidden = FALSE;
gint progressive_key_scrolling = FALSE;

gint startup_path_enable = FALSE;
gchar *startup_path = NULL;
gint confirm_delete = TRUE;
gint enable_delete_key = TRUE;
gint restore_tool = FALSE;
gint zoom_mode = ZOOM_RESET_ORIGINAL;
gint two_pass_zoom = TRUE;
gint fit_window = FALSE;
gint limit_window_size = FALSE;
gint zoom_to_fit_expands = TRUE;
gint max_window_size = 100;
gint thumb_max_width = 64;
gint thumb_max_height = 64;
gint enable_thumb_caching = TRUE;
gint enable_thumb_dirs = FALSE;
gint use_xvpics_thumbnails = TRUE;
gint show_dot_files = FALSE;
gint file_filter_disable = FALSE;
gchar *editor_name[8];
gchar *editor_command[8];

gint thumbnails_enabled = FALSE;
SortType file_sort_method = SORT_NAME;
gint file_sort_ascending = TRUE;

gint slideshow_delay = 15;
gint slideshow_random = FALSE;
gint slideshow_repeat = FALSE;

gint mousewheel_scrolls = TRUE;
gint enable_in_place_rename = TRUE;

gint recent_list_max = 10;

gint collection_rectangular_selection = FALSE;
gint collection_drop_insert = TRUE;

gint tile_cache_max = 10;
gint thumbnail_quality = (gint)GDK_INTERP_NEAREST;
gint zoom_quality = (gint)GDK_INTERP_NEAREST;
gint dither_quality = (gint)GDK_RGB_DITHER_NORMAL;

gint zoom_increment = 5;

gint enable_read_ahead = TRUE;

gint place_dialogs_under_mouse = FALSE;

gint black_window_background = FALSE;

gint dupe_custom_threshold = 99;

gint debug = FALSE;

/* logo & misc images */

const char **logo = (const char **)logo_xpm;
const char **img_unknown = (const char **)img_unknown_xpm;

/* layout */
gchar *layout_order = NULL;
gint layout_style = 0;

gint layout_view_icons = FALSE;
gint layout_view_tree = FALSE;

gint tree_descend_subdirs = FALSE;

gint lazy_image_sync = FALSE;
